==> dcoupon_sdk_flutter_package-1.1.3.tar.gz: lib/src/domain/usecases/coupon_create_user_coupons.dart <==
import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/coupon_repository.dart';
import 'package:equatable/equatable.dart';

class CouponCreateUserCoupons
    implements UseCase<dynamic, CouponCreateUserCouponsParams> {
  final CouponRepository repository;

  CouponCreateUserCoupons(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(
      CouponCreateUserCouponsParams params) async {
    return await repository.createUserCoupons(
      promotionTokens: params.promotionTokens,
      latitude: params.latitude,
      longitude: params.longitude,
      source: params.source,
      transId: params.transId,
      crmId: params.crmId,
      publisherName: params.publisherName,
    );
  }
}

class CouponCreateUserCouponsParams extends Equatable {
  final List<String> promotionTokens;
  final String latitude;
  final String longitude;
  final String source;
  final String transId;
  final String crmId;
  final String publisherName;

  CouponCreateUserCouponsParams({
    this.promotionTokens,
    this.latitude,
    this.longitude,
    this.source,
    this.transId,
    this.crmId,
    this.publisherName,
  });

  @override
  List<Object> get props => [
        promotionTokens,
        latitude,
        longitude,
        source,
        transId,
        crmId,
        publisherName,
      ];
}

==> dcoupon_sdk_flutter_package-4.0.1.tar.gz: lib/src/domain/usecases/coupon_create_user_coupons.dart <==
import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/coupon_repository.dart';
import 'package:equatable/equatable.dart';

class CouponCreateUserCoupons
    implements UseCase<dynamic, CouponCreateUserCouponsParams> {
  final CouponRepository? repository;

  CouponCreateUserCoupons(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(
      CouponCreateUserCouponsParams params) async {
    return await repository!.createUserCoupons(
      promotionTokens: params.promotionTokens,
      latitude: params.latitude,
      longitude: params.longitude,
      source: params.source,
      transId: params.transId,
      crmId: params.crmId,
      publisherToken: params.publisherToken,
    );
  }
}

class CouponCreateUserCouponsParams extends Equatable {
  final List<String>? promotionTokens;
  final String? latitude;
  final String? longitude;
  final String? source;
  final String? transId;
  final String? crmId;
  final String? publisherToken;

  CouponCreateUserCouponsParams({
    this.promotionTokens,
    this.latitude,
    this.longitude,
    this.source,
    this.transId,
    this.crmId,
    this.publisherToken,
  });

  @override
  List<Object?> get props => [
        promotionTokens,
        latitude,
        longitude,
        source,
        transId,
        crmId,
        publisherToken,
      ];
}
